FuldeKeyboardKey class

Virtual Keyboard key

Constructors

FuldeKeyboardKey({String? text, String? capsText, required FuldeKeyboardKeyType keyType, FuldeKeyboardKeyAction? action, List<int>? coords, String? latin, String? upper, String? fulde})

Properties

action FuldeKeyboardKeyAction?
final
capsText String?
getter/setter pair
coords List<int>?
getter/setter pair
fulde String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keyType FuldeKeyboardKeyType
final
latin String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
getter/setter pair
upper String?
getter/setter pair

Methods

getCoords() List<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited