FuldeKeyboardLayoutKeys class abstract
- Implementers
Constructors
Properties
- activeIndex ↔ int
-
getter/setter pair
-
activeLayout
→ List<
Map> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
newEnglishLayout
→ List<
Map> -
no setter
-
newFulbeLayout
→ List<
Map> -
no setter
-
newLatinLayout
→ List<
Map> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getLanguage(
int index) → List< Map> -
getLanguagesCount(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
switchLanguage(
int index) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited