VirtualKeyboardDefaultLayoutKeys class
- Inheritance
-
- Object
- FuldeKeyboardLayoutKeys
- VirtualKeyboardDefaultLayoutKeys
Constructors
-
VirtualKeyboardDefaultLayoutKeys(List<
FuldeKeyboardDefaultLayouts> defaultLayouts)
Properties
- activeIndex ↔ int
-
getter/setter pairinherited
-
activeLayout
→ List<
Map> -
no setterinherited
-
defaultLayouts
↔ List<
FuldeKeyboardDefaultLayouts> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
newEnglishLayout
→ List<
Map> -
no setterinherited
-
newFulbeLayout
→ List<
Map> -
no setterinherited
-
newLatinLayout
→ List<
Map> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getLanguage(
int index) → List< Map> -
override
-
getLanguagesCount(
) → int -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
switchLanguage(
int index) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited